.. _dmt_core:

DMT-core
====================

Inside the core all classes and routines which are needed everywhere in DMT and also outside of it, are collected. The abstract classes for the model cards and the simulators are implemented and the data handling is defined. Also the core has a pretty plotting class.

.. toctree::
    :maxdepth: 1
    :glob:

    ../core/*
